@@ -30,7 +30,6 @@ def get_view(url, project_path):
         contents = f.read()
 
     class_name = extract_function(contents, url)
-
     views_path = os.path.join(project_path, "views.py")
     spec = importlib.util.spec_from_file_location("views", str(views_path))
     views_module = importlib.util.module_from_spec(spec)
@@ -42,7 +41,10 @@ def get_view(url, project_path):
 
 def handle_request(project_name, path, method, form):
     # Handle the root route
-    response_body = get_view(path, project_name)
+    try:
+        response_body = get_view(path, project_name)
+    except:
+        return "HTTP/1.1 404 Not Found\nContent-Type: text/plain\nContent-Length: 9\n\nNot Found"
 
     if not response_body:
         return "HTTP/1.1 404 Not Found\nContent-Type: text/plain\nContent-Length: 9\n\nNot Found"
